@@ -38,7 +38,7 @@
 								FROM
 									".$dbprefix."blog";
 				if(!$_SESSION['right'][RIGHT_EDITALLENTRIES]){
-					$list_sql .= " and Autor = '".$_SESSION['UserID']."' ";
+					$list_sql .= " WHERE Autor = '".$_SESSION['UserID']."' ";
 				}
 				$list_sql .= "	ORDER BY
 									date DESC
@@ -125,11 +125,11 @@
 										FROM
 											".$dbprefix."blog
 										WHERE
-											ID = '".$_POST['ID']."';";
+											ID = '".$_POST['ID']."'";
 						if(!$_SESSION['right'][RIGHT_EDITALLENTRIES]){
-							$edit_sql .= " and Autor = '".$_SESSION['UserID']."';";
+							$edit_sql .= " and Autor = '".$_SESSION['UserID']."'";
 						}
-						$edit_res = $db->query($edit_sql);
+						$edit_res = $db->query($edit_sql . ';');
 						if($db->numrows($edit_res) > 0){
 							$edit = $db->fetch($edit_res);
 							$tpl->add_tpl('admin/blog_form.tpl');
@@ -260,11 +260,11 @@
 						$del_sql = "DELETE FROM
 										".$dbprefix."blog
 									WHERE
-										ID = '".$_POST['ID']."';";
+										ID = '".$_POST['ID']."'";
 						if(!$_SESSION['right'][RIGHT_EDITALLENTRIES]){
-							$del_sql .= " and Autor = '".$_SESSION['UserID']."';";
+							$del_sql .= " and Autor = '".$_SESSION['UserID']."'";
 						}
-						$db->query($del_sql);
+						$db->query($del_sql . ';');
 						$del_sql = "DELETE FROM
 										".$dbprefix."comments
 									WHERE
